#include <ccan/cdump/cdump.h>
/* Include the C files directly. */
#include <ccan/cdump/cdump.c>
#include <ccan/tap/tap.h>

int main(void)
{
	char c = 'A';
	unsigned char uc = 66;
	unsigned u = 0xdeadbeef;
	int i = -54;
	time_t t = 1000000;
	float f = 2.0;
	double d = 3.0;
	struct cdump_string *s;

	/* This is how many tests you plan to run */
	plan_tests(7 * 5);

	s = talloc(NULL, struct cdump_string);
	s->length = 0;
	s->s = NULL;

	ok1(cdump_bundle_char(s, &c, 0));
	ok1(strcmp(s->s, "65") == 0);
	ok1(s->length == strlen(s->s));
	ok1(cdump_unbundle_char(NULL, &c, s->s));
	ok1(c == 'A');
	s->length = 0;
	s->s = NULL;

	ok1(cdump_bundle_unsigned_char(s, &uc, 0));
	ok1(strcmp(s->s, "66") == 0);
	ok1(s->length == strlen(s->s));
	ok1(cdump_unbundle_unsigned_char(NULL, &uc, s->s));
	ok1(uc == 66);
	s->length = 0;
	s->s = NULL;

	ok1(cdump_bundle_int(s, &i, 0));
	ok1(strcmp(s->s, "-54") == 0);
	ok1(s->length == strlen(s->s));
	ok1(cdump_unbundle_int(NULL, &i, s->s));
	ok1(i == -54);
	s->length = 0;
	s->s = NULL;

	ok1(cdump_bundle_unsigned(s, &u, 0));
	ok1(strcmp(s->s, "3735928559") == 0);
	ok1(s->length == strlen(s->s));
	ok1(cdump_unbundle_unsigned(NULL, &u, s->s));
	ok1(u == 0xdeadbeef);
	s->length = 0;
	s->s = NULL;

	ok1(cdump_bundle_time_t(s, &t, 0));
	ok1(strcmp(s->s, "1000000") == 0);
	ok1(s->length == strlen(s->s));
	ok1(cdump_unbundle_time_t(NULL, &t, s->s));
	ok1(t == 1000000);
	s->length = 0;
	s->s = NULL;

	ok1(cdump_bundle_double(s, &d, 0));
	ok1(strcmp(s->s, "3") == 0);
	ok1(s->length == strlen(s->s));
	ok1(cdump_unbundle_double(NULL, &d, s->s));
	ok1(d == 3.0);
	s->length = 0;
	s->s = NULL;

	ok1(cdump_bundle_float(s, &f, 0));
	ok1(strcmp(s->s, "2") == 0);
	ok1(s->length == strlen(s->s));
	ok1(cdump_unbundle_float(NULL, &f, s->s));
	ok1(f == 2.0);
	s->length = 0;
	s->s = NULL;

	/* Everything should have been allocated off this, so no leaks. */
	talloc_free(s);

	/* This exits depending on whether all tests passed */
	return exit_status();
}
